@@ -18,7 +18,8 @@ trap "clean_exit ${MONGO_DATA}" EXIT
 mkfifo ${MONGO_DATA}/out
 mongod --maxConns 32 --nojournal --noprealloc --smallfiles --quiet --noauth --port ${MONGO_PORT} --dbpath "${MONGO_DATA}" --bind_ip localhost --config /dev/null &>${MONGO_DATA}/out &
 # Wait for Mongo to start listening to connections
-wait_for_line "waiting for connections on port ${MONGO_PORT}" ${MONGO_DATA}/out
+#wait_for_line "waiting for connections on port ${MONGO_PORT}" ${MONGO_DATA}/out
+sleep 10
 # Read the fifo for ever otherwise mongod would block
 cat ${MONGO_DATA}/out > /dev/null &
 export CEILOMETER_TEST_STORAGE_URL="mongodb://localhost:${MONGO_PORT}/ceilometer"
